@@ -4,15 +4,24 @@ use strict;
 use warnings;
 use parent qw(Plack::Middleware);
 use Scope::Container;
+use Plack::Util;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub call {
     my ( $self, $env) = @_;
     my $container = start_scope_container();
     my $res = $self->app->($env);
-    return $self->response_cb($res, sub {
-        undef $container;
+    Plack::Util::response_cb($res, sub {
+        my $res = shift;
+        return sub {
+            my $chunk = shift;
+            if ( ! defined $chunk ) {
+                undef $container;
+                return;
+            }
+            return $chunk;
+        };
     });
 }
 
